package com.dhcc.finance.main.service;

import java.util.List;

import com.dhcc.common.model.CurrencyMeta;
import com.dhcc.common.model.response.RestfulResponse;
import com.dhcc.finance.main.domain.CwBdVouchtempB;
import com.dhcc.finance.main.model.CwBdVouchtempBUpd;
import com.dhcc.finance.main.model.VouchtempBForTable;
import com.github.pagehelper.PageInfo;

/**
 * 功能描述：凭证模板分录配置接口
 * @author dml
 * @date 2019年3月27日 下午2:34:02
 * @修改日志：
 */
public interface CwBdVouchtempBService {
	/**
	 * 功能描述：查询全部凭证模板分录配置
	 * @param pageNum
	 * @param pageSize
	 * @param navigatePages
	 * @return RestfulResponse<PageInfo<CwBdVouchtempB>,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午1:54:05
	 * @修改日志：
	 */
	RestfulResponse<PageInfo<CwBdVouchtempB>, CurrencyMeta> searchCwBdVouchtempBAllData(int pageNum, int pageSize, int navigatePages,String pkVouchtemp);
	/**
	 * 功能描述：新增凭证模板分录配置
	 * @param cwBdVouchtempB
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午2:14:15
	 * @修改日志：
	 */
	RestfulResponse<Object, CurrencyMeta> addCwBdVouchtempB(CwBdVouchtempB cwBdVouchtempB);
	/**
	 * 功能描述：通过主键修改凭证模板分录配置
	 * @param cwBdVouchtempB
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午2:15:08
	 * @修改日志：
	 */
	RestfulResponse<Object, CurrencyMeta> updateCwBdVouchtempBByPk(CwBdVouchtempBUpd cwBdVouchtempBUpd);
	/**
	 * 功能描述：逻辑删除凭证模板分录配置
	 * @param pkVouchtempB
	 * @return RestfulResponse<Object,CurrencyMeta>
	 * @author dml
	 * @date 2019年3月27日 下午2:16:06
	 * @修改日志：
	 */
	RestfulResponse<Object, CurrencyMeta> deleteCwBdVouchtempBByPk(String pkVouchtempB);
	/**
	 * 功能描述：查询某分录模板下所有分录信息不分页
	 * @param pkVouchtemp
	 * @return RestfulResponse<PageInfo<CwBdVouchtempB>,CurrencyMeta>
	 * @author dml
	 * @date 2019年4月10日 下午2:26:16
	 * @修改日志：
	 */
	RestfulResponse<List<CwBdVouchtempB>, CurrencyMeta> searchCwBdVouchtempB(String pkVouchtemp);
	/**
	 * 功能描述  查询计算编辑器表名
	 *@param tableName
	 *@return RestfulResponse<List<VouchtempBForTable>,CurrencyMeta>
	 *@author huangpeng
	 *@date 2020年1月9日 上午11:55:15
	 *修改日志:
	 */
	RestfulResponse<List<VouchtempBForTable>, CurrencyMeta> searchCwBdVouchtempBForTableName(String tableName);
	


}
